| irtc.mml.2pl | R Documentation |
Estimates unidimensional and multidimensional item response models with
estimated item slopes (discriminations) by marginal maximum likelihood
(MML). Supported models are the two-parameter logistic model ("2PL"),
the generalized partial credit model ("GPCM"), their design-matrix
and slope-group variants ("GPCM.design", "2PL.groups",
"GPCM.groups").
irtc.mml.2pl(resp, Y = NULL, group = NULL, irtmodel = "2PL",
formulaY = NULL, dataY = NULL, ndim = 1, pid = NULL,
xsi.fixed = NULL, xsi.inits = NULL, beta.fixed = NULL, beta.inits = NULL,
variance.fixed = NULL, variance.inits = NULL, est.variance = FALSE,
A = NULL, B = NULL, B.fixed = NULL, Q = NULL, est.slopegroups = NULL,
E = NULL, gamma.init = NULL, pweights = NULL, userfct.variance = NULL,
variance.Npars = NULL, item.elim = TRUE, verbose = TRUE,
method = c("auto", "grid", "streaming"), control = list())
resp |
A data frame or matrix of item responses ( |
Y |
Optional covariate matrix for the latent regression. |
group |
Optional integer vector of group identifiers for multiple groups. |
irtmodel |
The estimated model: one of |
formulaY |
Optional formula for the latent regression (with |
dataY |
Optional covariate data frame used with |
ndim |
Number of latent dimensions (when no |
pid |
Optional vector of person identifiers. |
xsi.fixed |
Optional matrix (index, value) fixing item intercept parameters. |
xsi.inits |
Optional matrix of initial item parameters. |
beta.fixed |
Optional matrix fixing regression coefficients, or |
beta.inits |
Optional matrix of initial regression coefficients. |
variance.fixed |
Optional matrix fixing covariance entries. |
variance.inits |
Optional initial covariance matrix. |
est.variance |
Logical: estimate the covariance matrix? (default |
A |
Optional design array for item intercepts. |
B |
Optional design array for item slopes. |
B.fixed |
Optional matrix fixing entries of the slope array |
Q |
Optional loading (Q-) matrix mapping items to dimensions. |
est.slopegroups |
Optional vector grouping items that share a common estimated slope. |
E |
Optional design array used with |
gamma.init |
Optional initial values for the estimated slope parameters. |
pweights |
Optional vector of person (case) weights. |
userfct.variance |
Optional user function constraining the covariance matrix. |
variance.Npars |
Number of estimated parameters in a user-constrained covariance. |
item.elim |
Logical: eliminate items with empty response categories? |
verbose |
Logical: print estimation progress? |
method |
Estimation engine. |
control |
List of control arguments (e.g. When |
An object of class irtc (see irtc.mml) with, in addition,
the estimated slope array B and the slope parameter vector. Streaming-engine
fits also carry a routing component (chosen engine and reasoning) and, when
fast=TRUE with verification on, an accuracy_report: a measured,
stratified approximation check (per-metric error quantiles plus a met
verdict), not a strict mathematical error bound.
irtc.mml for fixed-slope (Rasch / PCM / RSM) models.
data(data.sim.rasch)
mod1 <- irtc.mml.2pl(resp = data.sim.rasch, irtmodel = "2PL")
summary(mod1)
data(data.gpcm)
mod2 <- irtc.mml.2pl(resp = data.gpcm, irtmodel = "GPCM")
summary(mod2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.